==> haskell-expiring-cache-map-0.0.6.1-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-5cikrkFxXP7Fldcd0ytUJa
key: expiring-cache-map-0.0.6.1-5cikrkFxXP7Fldcd0ytUJa
license: BSD-3-Clause
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
author: Edward L. Blake
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
abi: 8e28b5b324b8e0dbcbac262fb17ae43f
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-5cikrkFxXP7Fldcd0ytUJa
depends:
    base-4.12.0.0 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-DLDkoY7TJ6XHcgd23RNoVw
key: expiring-cache-map-0.0.6.1-DLDkoY7TJ6XHcgd23RNoVw
license: BSD-3-Clause
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
author: Edward L. Blake
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
abi: 7eecc89d8accfecca420de8fd41ba77d
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-DLDkoY7TJ6XHcgd23RNoVw
depends:
    base-4.12.0.0 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    unordered-containers-0.2.10.0-9wTHYlaSuHyGA5dBBp2WV8
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
